#ifndef NT2_INCLUDE_FUNCTIONS_INTERLEAVE_FIRST_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_INTERLEAVE_FIRST_HPP_INCLUDED

#include <nt2/swar/include/functions/interleave_first.hpp>

#endif
